<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'Reen al kompleta grafika interfaco',
	'access_mode_texte' => 'Afiŝi la simpligitan tekstan interfacon',
	'admin_debug' => 'erarserĉilo',
	'admin_modifier_article' => 'Modifu tiun ĉi artikolon',
	'admin_modifier_auteur' => 'Modifu tiun ĉi aŭtoron',
	'admin_modifier_breve' => 'Modifu tiun ĉi fulm-informon',
	'admin_modifier_mot' => 'Modifu tiun ĉi ŝlosilvorton',
	'admin_modifier_rubrique' => 'Modifu tiun ĉi rubrikon',
	'admin_recalculer' => 'Rekalkulu tiun ĉi paĝon',
	'afficher_calendrier' => 'Montri la kalendaro',
	'afficher_trad' => 'afiŝi la tradukojn',
	'alerte_maj_impossible' => '<b>Alarmo !</b> La ĝisdatigo de la SQL-datenbazo al versio @version@ ne eblas pro datenbazo-modif-rajtaj kialoj. Bonvolu kontakti vian retgastiganton.',
	'alerte_modif_info_concourante' => 'ATENTU : Tiu ĉi informo estis modifita de alia homo. La nuna stato estas :',
	'analyse_xml' => 'XML analizo',
	'annuler' => 'Nuligi',
	'antispam_champ_vide' => 'Bonvolu forlasi tiun tajpujon malplena :',
	'articles_recents' => 'La plej freŝaj artikoloj',
	'avis_1_erreur_saisie' => 'Estas 1 eraro en via tajpado, bonvolu kontroli ĝin.',
	'avis_archive_incorrect' => 'Tiu arkivo ne estas SPIP-dosiero',
	'avis_archive_invalide' => 'Tiu arkiva dosiero ne validas',
	'avis_attention' => 'ATENTU !',
	'avis_champ_incorrect_type_objet' => 'Erara tajpuja nomo @name@ por la objekto de tipo @type@',
	'avis_colonne_inexistante' => 'La kolumno @col@ ne ekzistas',
	'avis_erreur' => 'Eraro : vidu ĉi-sube',
	'avis_erreur_connexion' => 'Konekt-eraro',
	'avis_erreur_cookie' => 'kuketo-problemo',
	'avis_erreur_fonction_contexte' => 'Program-eraro. Tiu funkcio ne alvokeblas en tiu ĉi kunteksto.',
	'avis_erreur_mysql' => 'SQL-eraro',
	'avis_erreur_sauvegarde' => 'Konservo-eraro (@type@ @id_objet@) ! ',
	'avis_erreur_visiteur' => 'Alir-problemo al la privata spaco',
	'avis_nb_erreurs_saisie' => 'Estas @nb@ eraroj en via tajpado, bonvolu kontroli ilin.',

	// B
	'barre_a_accent_grave' => 'Entajpi malakut-akcentan ĉefliteran A',
	'barre_aide' => 'Uzu la tipografiajn rapidligilojn por pliriĉigi vian enpaĝigon',
	'barre_e_accent_aigu' => 'Entajpi malakut-akcentan ĉefliteran E',
	'barre_eo' => 'Entajpi E en ĉefliteran O',
	'barre_eo_maj' => 'Entajpi E en la ĉeflitero O',
	'barre_euro' => 'Entajpi la simbolon €',
	'barre_gras' => '{{Grasigi}}',
	'barre_guillemets' => 'Flanki per « citiloj »',
	'barre_guillemets_simples' => 'Flanki per simplaj citiloj',
	'barre_intertitre' => '{{{Intertitoligi}}}',
	'barre_italic' => '{Kursivigi}',
	'barre_lien' => 'Transformi al [hiperligo->http://...]',
	'barre_lien_input' => 'Bonvolu indiki la retadreson de via ligilo (vi povas indiki ret-adreson tian, kia http://www.monsite.com aŭ simple indiki la numeron de artikolo de tiu retejo.',
	'barre_note' => 'Transformi al [[sub-paĝan noton]]',
	'barre_paragraphe' => 'Krei paragrafon',
	'barre_quote' => '<quote>Citi mesaĝon</quote>',
	'bouton_changer' => 'Ŝanĝi',
	'bouton_chercher' => 'Serĉi',
	'bouton_choisir' => 'Elekti',
	'bouton_deplacer' => 'Movi',
	'bouton_download' => 'Elŝuti',
	'bouton_enregistrer' => 'Registri',
	'bouton_radio_desactiver_messagerie_interne' => 'Malŝalti la internan mesaĝilon',
	'bouton_radio_envoi_annonces' => 'Sendi la ĉefartikolajn anoncojn',
	'bouton_radio_non_envoi_annonces' => 'Ne sendi anoncojn',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Ne sendi liston de novaĵoj',
	'bouton_recharger_page' => 'freŝigi tiun paĝon',
	'bouton_telecharger' => 'Alŝuti',
	'bouton_upload' => 'Alŝuti',
	'bouton_valider' => 'Validigi',

	// C
	'cal_apresmidi' => 'posttagmezo',
	'cal_jour_entier' => 'tuta tago',
	'cal_matin' => 'mateno',
	'cal_par_jour' => 'tag-kalendaro',
	'cal_par_mois' => 'monat-kalendaro',
	'cal_par_semaine' => 'semajn-kalendaro',
	'choix_couleur_interface' => 'koloro',
	'choix_interface' => 'elekto de interfaco',
	'colonne' => 'Kolumno',
	'confirm_changer_statut' => 'Atentu, vi petis por ŝanĝi la statuton de tiu elemento. Ĉu vi deziras daŭrigi ?',
	'correcte' => 'korekta',

	// D
	'date_aujourdhui' => 'hodiaŭ',
	'date_avant_jc' => 'a.K.',
	'date_dans' => 'post @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'morgaŭ',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_heures_minutes_court' => '@h@h@m@',
	'date_fmt_jour' => '@nomjour@ la @jour@a',
	'date_fmt_jour_heure' => '@jour@ je la @heure@',
	'date_fmt_jour_heure_debut_fin' => 'la @jour@ de @heure_debut@ ĝis @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => 'la @dtstart@@jour@a de @heure_debut@@dtabbr@ ĝis @dtend@@heure_fin@@dtend@',
	'date_fmt_jour_mois' => '@jour@a @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@a @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => 'la @nomjour@ @date@',
	'date_fmt_periode' => 'De @date_debut@ ĝis @date_fin@',
	'date_fmt_periode_abbr' => 'De @dtart@@date_debut@@dtabbr@ ĝis @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'De',
	'date_fmt_periode_to' => 'ĝis',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'horoj',
	'date_hier' => 'hieraŭ',
	'date_il_y_a' => 'antaŭ @delai@',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'dimanĉo',
	'date_jour_1_abbr' => 'dim.',
	'date_jour_1_initiale' => 'd.',
	'date_jour_2' => 'lundo',
	'date_jour_2_abbr' => 'lun.',
	'date_jour_2_initiale' => 'l.',
	'date_jour_3' => 'mardo',
	'date_jour_3_abbr' => 'mar.',
	'date_jour_3_initiale' => 'm.',
	'date_jour_4' => 'merkredo',
	'date_jour_4_abbr' => 'mer.',
	'date_jour_4_initiale' => 'm.',
	'date_jour_5' => 'ĵaŭdo',
	'date_jour_5_abbr' => 'jaŭ.',
	'date_jour_5_initiale' => 'j.',
	'date_jour_6' => 'vendredo',
	'date_jour_6_abbr' => 'ven.',
	'date_jour_6_initiale' => 'v.',
	'date_jour_7' => 'sabato',
	'date_jour_7_abbr' => 'sab.',
	'date_jour_7_initiale' => 's.',
	'date_jours' => 'tagoj',
	'date_minutes' => 'minutoj',
	'date_mois' => 'monatoj',
	'date_mois_1' => 'januaro',
	'date_mois_10' => 'oktobro',
	'date_mois_10_abbr' => 'oct.',
	'date_mois_11' => 'novembro',
	'date_mois_11_abbr' => 'nov.',
	'date_mois_12' => 'decembro',
	'date_mois_12_abbr' => 'dec.',
	'date_mois_1_abbr' => 'jan.',
	'date_mois_2' => 'februaro',
	'date_mois_2_abbr' => 'feb.',
	'date_mois_3' => 'marto',
	'date_mois_3_abbr' => 'mar.',
	'date_mois_4' => 'aprilo',
	'date_mois_4_abbr' => 'apr.',
	'date_mois_5' => 'majo',
	'date_mois_5_abbr' => 'majo',
	'date_mois_6' => 'junio',
	'date_mois_6_abbr' => 'jun.',
	'date_mois_7' => 'julio',
	'date_mois_7_abbr' => 'jul.',
	'date_mois_8' => 'aŭgusto',
	'date_mois_8_abbr' => 'aŭg.',
	'date_mois_9' => 'septembro',
	'date_mois_9_abbr' => 'sep.',
	'date_saison_1' => 'vintro',
	'date_saison_2' => 'printempo',
	'date_saison_3' => 'somero',
	'date_saison_4' => 'aŭtuno',
	'date_secondes' => 'sekundoj',
	'date_semaines' => 'semajnoj',
	'date_un_mois' => 'monato',
	'date_une_heure' => 'horo',
	'date_une_minute' => 'minuto',
	'date_une_seconde' => 'sekundo',
	'date_une_semaine' => 'semajno',
	'dirs_commencer' => ' por vere komenci la instalprocezon',
	'dirs_preliminaire' => 'Antaŭfaro : <b>Difinu la alir-rajtojn</b>',
	'dirs_probleme_droits' => 'Alir-rajta problemo',
	'dirs_repertoires_absents' => '<b>La jenaj dosierujoj ne estas trovitaj : <ul>@bad_dirs@.</ul> </b>
  <p>La problemo verŝajne rilatas al majuskligo de literoj.
  Kontrolu ke la majuskloj ja kongruas kun tio kio estas afiŝita ĉi-supre ;
  se ili ne kongruas, bonvolu renomi la dosierujon per via FTP-programo por korekti la eraron.
</p><p>Post tio, vi povos</p>',
	'dirs_repertoires_suivants' => '<b>La jenaj dosierujoj ne estas skribe modifeblaj : 
<ul>@bad_dirs@.</ul></b>
<p>Por solvi tion, uzu vian FTP-klienton por reguligi la alir-rajtojn de ĉiu
 el tiuj dosierujoj. La proceduron oni detale klarigas en la instalgvidlibro.
</p><p>Post tio, vi povos </p>',
	'double_occurrence' => 'Duobla trafo de @balise@',

	// E
	'en_cours' => 'okazanta',
	'envoi_via_le_site' => 'Sendo tra la retejo',
	'erreur' => 'Eraro',
	'erreur_balise_non_fermee' => 'lasta ne fermita marko :',
	'erreur_technique_ajaxform' => 'Aj. Neatendita eraro ne ebligis la sendon de la formularo. Vi povas reprovi denove.',
	'erreur_technique_enregistrement_champs' => 'Teknika eraro neebligis la ĝustan registradon de la kampo @champs@.',
	'erreur_technique_enregistrement_impossible' => 'Teknika eraro neebligis la registradon.',
	'erreur_texte' => 'eraro(j)',
	'etape' => 'Etapo',

	// F
	'fichier_introuvable' => 'Netrovebla dosiero @fichier@ ', # MODIF
	'form_auteur_confirmation' => 'Konfirmu vian retpoŝtadreso',
	'form_auteur_email_modifie' => 'Via retpoŝtadreso estis modifita.',
	'form_auteur_envoi_mail_confirmation' => 'Konfirmretmesaĝo estis sendita al @email@. Vi devu viziti la menciita retadreso en la retmesaĝo por validigi vian retpoŝtadreson.',
	'form_auteur_mail_confirmation' => 'Saluton,

Vi petis ŝanĝi vian retpoŝtadreson.
Por konfirmi vian novan retadreson, simple ensaluti al
la retadreso ĉi-sube (alie, via peto estos ignoritaj) :

    @url@',
	'form_deja_inscrit' => 'Vi estas jam registrita.',
	'form_email_non_valide' => 'Via retpoŝtadreso ne validas.',
	'form_forum_access_refuse' => 'Vi ne plu havas alir-rajton al tiu retejo.',
	'form_forum_bonjour' => 'Saluton @nom@,',
	'form_forum_confirmer_email' => 'Por konfirmi vian retpoŝtadreson, iru al tiu retadreso : @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Tiu ĉi retpoŝtadreso estas jam registrita, vi povas do uzi vian kutiman pasvorton.',
	'form_forum_identifiant_mail' => 'Via nova ensalutilo estis ĵus al vi sendita per retletero.',
	'form_forum_identifiants' => 'Personaj ensalutiloj',
	'form_forum_indiquer_nom_email' => 'Indiku ĉi tie vian nomon kaj retpoŝtadreson. Via persona ensalutilo rapide alvenos al vi retletere.',
	'form_forum_login' => 'salutnomo :',
	'form_forum_message_auto' => '(tio estas aŭtomata mesaĝo)',
	'form_forum_pass' => 'pasvorto :',
	'form_forum_probleme_mail' => 'Retpoŝta problemo : la ensalutilo ne sendeblas.',
	'form_forum_voici1' => 'Jen viaj ensalutiloj por partopreni la vivon de la retejo "@nom_site_spip@" (@adresse_site@) :',
	'form_forum_voici2' => 'Jen estas viaj ensalutiloj por proponi artikolojn ĉe la retejo "@nom_site_spip@" (@adresse_login@) :',
	'form_indiquer_email' => 'Bonvolu indiki vian retpoŝtadreson.',
	'form_indiquer_nom' => 'Bonvolu indiki vian nomon.',
	'form_indiquer_nom_site' => 'Bonvolu indiki la nomon de via retejo.',
	'form_pet_deja_enregistre' => 'Tiu retejo estas jam registrita',
	'form_pet_signature_pasprise' => 'Via subskribo ne estas registrita.',
	'form_prop_confirmer_envoi' => 'Konfirmi la sendon',
	'form_prop_description' => 'Priskribo/komento',
	'form_prop_enregistre' => 'Via kontribuo estas registrita, ĝi aperos ĉerete post validigo de la respondeculoj de la retejo.', # MODIF
	'form_prop_envoyer' => 'Sendi mesaĝon',
	'form_prop_indiquer_email' => 'Bonvolu indiki validan retpoŝtadreson',
	'form_prop_indiquer_nom_site' => 'Bonvolu indiki la nomon de la retejo.',
	'form_prop_indiquer_sujet' => 'Bonvolu indiki temon',
	'form_prop_message_envoye' => 'Mesaĝo sendita',
	'form_prop_non_enregistre' => 'Via propono ne estis registrita.',
	'form_prop_sujet' => 'Temo',
	'form_prop_url_site' => 'URL-adreso de la retejo',
	'format_date_incorrecte' => 'La dato aŭ ĝia formo ne validas',
	'format_heure_incorrecte' => 'La horo aŭ ĝia formo ne validas',
	'forum_non_inscrit' => 'Vi ne estas registrita, aŭ la adreso aŭ la pasvorto ne ĝustas.',
	'forum_par_auteur' => 'de @auteur@',
	'forum_titre_erreur' => 'Eraro...',

	// I
	'ical_texte_rss_articles' => 'La abondosiero (backend-dosiero) de la artikoloj de tiu retejo troveblas ĉe la retadreso :',
	'ical_texte_rss_articles2' => 'Sube, vi povas trovi abonligojn por gvati evoluadon de artikoloj el ĉiu rubriko de la retejo :',
	'ical_texte_rss_breves' => 'Krome ekzistas dosiero enhavanta ĉiujn fulm-informojn de la retejo. Precizigante la rubriko-numeron, vi ricevos nur la fulm-informojn el tiu rubriko.',
	'icone_a_suivre' => 'Stabejo',
	'icone_admin_site' => 'Reteja administrado',
	'icone_agenda' => 'Agendo',
	'icone_aide_ligne' => 'Helpilo',
	'icone_articles' => 'Artikoloj',
	'icone_auteurs' => 'Aŭtoroj',
	'icone_brouteur' => 'Rapida retumado',
	'icone_configuration_site' => 'Konfiguro',
	'icone_configurer_site' => 'Konfiguri vian retejon',
	'icone_creer_nouvel_auteur' => 'Krei novan aŭtoron',
	'icone_creer_rubrique' => 'Krei novan rubrikon',
	'icone_creer_sous_rubrique' => 'Krei sub-rubrikon',
	'icone_deconnecter' => 'Elsaluti',
	'icone_discussions' => 'Diskutoj',
	'icone_doc_rubrique' => 'Dokumentoj de la rubrikoj',
	'icone_ecrire_article' => 'Skribi novan artikolon',
	'icone_edition_site' => 'Redaktejo',
	'icone_gestion_langues' => 'Mastrumado de lingvoj',
	'icone_informations_personnelles' => 'Personaj datenoj',
	'icone_interface_complet' => 'kompleta interfaco',
	'icone_interface_simple' => 'Simpla interfaco',
	'icone_maintenance_site' => 'Retejo-bontenado',
	'icone_messagerie_personnelle' => 'Persona mesaĝilo',
	'icone_repartition_debut' => 'Afiŝi la distribuon ekde la komenco',
	'icone_rubriques' => 'Rubrikoj',
	'icone_sauver_site' => 'Savkopii la retejon',
	'icone_site_entier' => 'La tuta retejo',
	'icone_sites_references' => 'Referencigitaj retejoj',
	'icone_statistiques' => 'Statistikoj de la retejo',
	'icone_suivi_activite' => 'Gvati vivon de la retejo',
	'icone_suivi_actualite' => 'Evoluado de la retejo',
	'icone_suivi_pettions' => 'Superrigardi/mastrumi la petskribon',
	'icone_suivi_revisions' => 'Modifoj de artikoloj',
	'icone_supprimer_document' => 'Forigi tiun dokumenton',
	'icone_supprimer_image' => 'Forigi tiun bildon',
	'icone_tous_articles' => 'Ĉiuj viaj artikoloj',
	'icone_tous_auteur' => 'Ĉiuj aŭtoroj',
	'icone_tous_visiteur' => 'Ĉiuj vizitantoj',
	'icone_visiter_site' => 'Vidi la publikan spacon',
	'icone_voir_en_ligne' => 'Vidi ĉeretigite',
	'img_indisponible' => 'nedisponebla bildo',
	'impossible' => 'ne eblas',
	'info_a_suivre' => 'STABEJO »',
	'info_acces_interdit' => 'Malpermesata aliro',
	'info_acces_refuse' => 'Rifuzita aliro',
	'info_action' => 'Ago : @action@',
	'info_administrer_rubriques' => 'Vi povas mastrumi tiun rubrikon kaj ties subrubrikojn',
	'info_adresse_non_indiquee' => 'Vi indikis neniun adreson por testi !',
	'info_aide' => 'HELPO :',
	'info_ajouter_mot' => 'Aldoni tiun vorton',
	'info_annonce' => 'ANONCO',
	'info_annonces_generales' => 'Ĝeneralaj anoncoj :',
	'info_article_propose' => 'Proponita artikolo',
	'info_article_publie' => 'Publikigita artikolo',
	'info_article_redaction' => 'Redaktata artikolo',
	'info_article_refuse' => 'Rifuzita artikolo',
	'info_article_supprime' => 'Forviŝita artikolo',
	'info_articles' => 'Artikoloj',
	'info_articles_a_valider' => 'Validigendaj artikoloj',
	'info_articles_nb' => '@nb@ artikoloj',
	'info_articles_proposes' => 'Proponitaj artikoloj',
	'info_articles_un' => '1 artikolo',
	'info_auteurs_nombre' => 'aŭtoro(j) :',
	'info_authentification_ftp' => 'Aŭtentigo (per FTP).',
	'info_breves_2' => 'fulm-informoj',
	'info_breves_nb' => '@nb@ fulm-informoj',
	'info_breves_un' => '1 fulm-informo',
	'info_connexion_refusee' => 'Konektiĝo rifuzata',
	'info_contact_developpeur' => 'Bonvolu kontakti programiston.', # MODIF
	'info_contenance' => 'Tiu retejo enhavas :',
	'info_contribution' => 'kontribuaĵoj',
	'info_copyright' => '@spip@ estas libera programo distribuata @lien_gpl@.',
	'info_copyright_doc' => 'Por pliaj informoj vidu la retpaĝon <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'sub licenco GPL',
	'info_cours_edition' => 'Viaj redaktataj artikoloj', # MODIF
	'info_creer_repertoire' => 'Bonvolu krei dosieron aŭ dosierujon kies nomo estu :',
	'info_creer_repertoire_2' => 'ene de la subdosierujo <b>@repertoire@</b>, kaj :',
	'info_creer_vignette' => 'aŭtomata kreo de la vinjeto',
	'info_creerdansrubrique_non_autorise' => 'Vi ne havas sufiĉajn rajtojn por krei enhavo en ĉi tiu rubriko',
	'info_deplier' => 'Malfaldi',
	'info_descriptif_nombre' => 'priskribo(j) :',
	'info_description' => 'Priskribo :',
	'info_description_2' => 'Priskribo :',
	'info_dimension' => 'Dimensioj :',
	'info_documents_nb' => '@nb@ dokumentoj',
	'info_documents_un' => '1 dokumento',
	'info_ecire_message_prive' => 'Skribi privatan mesaĝon',
	'info_email_invalide' => 'Nevalida retpoŝtadreso.',
	'info_en_cours_validation' => 'Viaj redaktataj artikoloj',
	'info_en_ligne' => 'Nun ĉerete :',
	'info_envoyer_message_prive' => 'Sendi privatan mesaĝon al tiu ĉi aŭtoro',
	'info_erreur_requete' => 'Eraro en la peto : ',
	'info_erreur_squelette2' => 'Neniu skeleto <b>@fichier@</b> disponeblas...',
	'info_erreur_systeme' => 'Sistemo-eraro (errno @errsys@)',
	'info_erreur_systeme2' => 'Eble la fiksdisko plenas, aŭ la datenbazo estas difektita.<br />
<span style="color:red;">Provu<a href=\'@script@\'>ripari la datenbazon</a>,
aŭ kontaktu vian retgastiganton.</span>',
	'info_fini' => 'Finite !',
	'info_format_image' => 'Bildaj formatoj uzeblaj por krei vinjetojn : @gd_formats@.',
	'info_format_non_defini' => 'nedefinita formato',
	'info_grand_ecran' => 'Granda ekrano',
	'info_image_aide' => 'HELPILO',
	'info_image_process_titre' => 'Metodo pri vinjet-farado',
	'info_impossible_lire_page' => '<b>Eraro !</b> Ne eblas legi la paĝon <tt> <html>@test_proxy@</html> </tt> tra la prokura servilo <tt>',
	'info_installation_systeme_publication' => 'Instalo de la publikiga sistemo...',
	'info_installer_documents' => 'Vi povas aŭtomate instali ĉiujn dokumentojn troviĝantajn en la dosiero @upload@.',
	'info_installer_ftp' => 'Kiel mastrumanto, vi povas instali (FTP-e) dosierojn en la dosierujon @upload@ kaj poste rekte selekti ilin ĉi tie.', # MODIF
	'info_installer_images' => 'Vi povas instali bildojn je la formatoj JPEG, GIF kaj PNG.',
	'info_installer_images_dossier' => 'Instali bildojn en la dosierujon @upload@ por povi ilin selekti ĉi tie.',
	'info_interface_complete' => 'kompleta interfaco',
	'info_interface_simple' => 'Simpla interfaco',
	'info_joindre_document_article' => 'Vi povas ligi kun tiu artikolo dokumentojn tiajn, kiaj',
	'info_joindre_document_rubrique' => 'Vi povas ligi kun tiu rubriko dokumentojn tiajn, kiaj',
	'info_joindre_documents_article' => 'Vi povas ligi kun tiu artikolo dokumentojn tiajn, kiaj :',
	'info_l_article' => 'la artikolo',
	'info_la_breve' => 'la fulm-informo',
	'info_la_rubrique' => 'la rubriko',
	'info_langue_principale' => 'Ĉefa lingvo de la retejo',
	'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ bilderoj',
	'info_les_auteurs_1' => 'de @les_auteurs@',
	'info_logo_format_interdit' => 'Nur vinjetoj je formatoj @formats@ estas permesataj.',
	'info_logo_max_poids' => 'Vinjetoj devige pezu malpli ol @maxi@ (tiu dosiero pezas @actuel@).',
	'info_mail_fournisseur' => 'vi@retalir-provizisto.com',
	'info_message_2' => 'MESAĜO',
	'info_message_supprime' => 'FORIGITA MESAĜO',
	'info_messages_nb' => '@nb@ mesaĝoj',
	'info_messages_un' => '1 mesaĝo',
	'info_mise_en_ligne' => 'Dato de ĉeretigo : ',
	'info_modification_parametres_securite' => 'modifoj de la sekuraj parametroj',
	'info_mois_courant' => 'En la kuranta monato :',
	'info_mot_cle_ajoute' => 'La jena ŝlosilvorto estas ligita kun',
	'info_multi_herit' => 'Defaŭlta lingvo',
	'info_multi_langues_soulignees' => 'Por la <u>substrekitaj lingvoj</u>, ĉiuj tekstoj de la interfaco estas tute aŭ parte tradukitaj. Kiam vi elektas tiujn lingvojn, multaj elementoj de la publika retejo (datenoj, formularoj) estos aŭtomate tradukitaj. Por la nesubstrekitaj lingvoj, tiuj elementoj afiŝiĝos en la ĉefa lingvo de la retejo.',
	'info_multilinguisme' => 'Multlingvismo',
	'info_nom_non_utilisateurs_connectes' => 'Via nomo ne aperas en la listo de la ensalutintaj uzantoj.', # MODIF
	'info_nom_utilisateurs_connectes' => 'Via nomo aperas en la listo de la ensalutintaj uzantoj.', # MODIF
	'info_nombre_en_ligne' => 'Nun ensalutintaj :',
	'info_non_resultat' => 'Neniu rezulto por "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Vi ne uzas la internan mesaĝilon de tiu retejo.',
	'info_nouveau_message' => 'VI HAVAS NOVAN MESAĜON',
	'info_nouveaux_messages' => 'VI HAVAS @total_messages@ NOVA(J)N MESAĜO(J)N',
	'info_numero_abbreviation' => 'N° ',
	'info_obligatoire' => 'Tiu ĉi informo estas deviga',
	'info_pense_bete' => 'MEMORIGILO',
	'info_petit_ecran' => 'Eta ekrano',
	'info_petition_close' => 'Petskribo fermita',
	'info_pixels' => 'bilderoj',
	'info_plusieurs_mots_trouves' => 'Pluraj ŝlosilvortoj trovitaj por "@cherche_mot@" :',
	'info_portfolio_automatique' => 'Aŭtomata dokumentujo :',
	'info_premier_resultat' => '[@debut_limit@ unuaj rezultoj el @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ unuaj rezultoj el @total@]',
	'info_propose_1' => '[@nom_site_spip@] Proponas : @titre@',
	'info_propose_2' => 'Proponita artikolo
---------------',
	'info_propose_3' => 'La artikolo "@titre@" estas proponita por publikigo.',
	'info_propose_4' => 'Vi estas petata konsulti ĝin kaj doni vian opinion',
	'info_propose_5' => 'en la forumo ligita al ĝi. Ĝi estas disponebla el la adreso :',
	'info_publie_01' => 'La artikolo "@titre@" estis validigita de @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLIKIGAS : @titre@',
	'info_publie_2' => 'Artikolo publikigita
--------------',
	'info_rechercher' => 'Serĉi',
	'info_rechercher_02' => 'Serĉi :',
	'info_remplacer_vignette' => 'Anstataŭi la defaŭltan vinjeton per propra vinjeto :',
	'info_rubriques_nb' => '@nb@ rubrikoj',
	'info_rubriques_un' => '1 rubriko',
	'info_sans_titre_2' => 'sen titolo',
	'info_selectionner_fichier' => 'Vi povas selekti dosieron el la dosierujo @upload@',
	'info_selectionner_fichier_2' => 'Elektu dosieron :',
	'info_sites_nb' => '@nb@ retejoj',
	'info_sites_un' => '1 retejo',
	'info_supprimer_vignette' => 'forigi la vinjeton',
	'info_symbole_bleu' => 'La <b>blua</b> simbolo indikas <b>memorigilon</b> : tio estas al vi persone adresata memoriga mesaĝo.',
	'info_symbole_jaune' => 'La <b>flava</b> simbolo indikas <b>anoncon al ĉiuj redaktantoj</b> : modifebla de ĉiuj mastrumantoj, kaj videbla de ĉiuj redaktantoj.', # MODIF
	'info_symbole_vert' => 'La <b>verda</b> simbolo indikas la <b>mesaĝojn interŝanĝitajn kun aliaj uzantoj</b> de la retejo.', # MODIF
	'info_telecharger_nouveau_logo' => 'Alŝuti novan vinjeton :',
	'info_telecharger_ordinateur' => 'Alŝuti ekde via komputilo :',
	'info_tous_resultats_enregistres' => '[ĉiuj rezultoj estas registritaj]',
	'info_tout_afficher' => 'Ĉion afiŝi',
	'info_travaux_texte' => 'Tiu retejo ne jam estas konfigurita. Bonvolu reveni poste...',
	'info_travaux_titre' => 'Retejo prilaborata ',
	'info_trop_resultat' => 'Tro da rezultoj por "@cherche_mot@" ; bonvolu fajnigi la serĉokriteriojn.',
	'info_utilisation_messagerie_interne' => 'Vi uzas la internan poŝton de tiu ĉi retejo.',
	'info_valider_lien' => 'validigi tiun ĉi ligilon',
	'info_verifier_image' => ', bonvolu kontroli ĉu viaj bildoj estas trafe transigitaj.',
	'info_vignette_defaut' => 'Defaŭlta vinjeto',
	'info_vignette_personnalisee' => 'Persona vinjeto',
	'info_visite' => 'vizito :',
	'info_vos_rendez_vous' => 'Viaj estontaj rendevuoj',
	'infos_vos_pense_bete' => 'Viaj memorigiloj',

	// L
	'label_ajout_id_rapide' => 'Rapida aldono',
	'label_poids_fichier' => 'Grandeco',
	'lien_afficher_icones_seuls' => 'Afiŝi nur la piktogramojn',
	'lien_afficher_texte_icones' => 'Afiŝi la piktogramojn kaj la tekston',
	'lien_afficher_texte_seul' => 'Afiŝi nur la tekston',
	'lien_liberer' => 'liberigi',
	'lien_liberer_tous' => 'Liberigi ĉiujn',
	'lien_nouvea_pense_bete' => 'NOVA MEMORIGILO',
	'lien_nouveau_message' => 'NOVA MESAĜO',
	'lien_nouvelle_annonce' => 'NOVA ANONCO',
	'lien_petitions' => 'PETSKRIBO',
	'lien_popularite' => 'populareco : @popularite@%',
	'lien_racine_site' => 'RADIKO DE LA RETEJO',
	'lien_reessayer' => 'reprovi',
	'lien_repondre_message' => 'Respondi al tiu mesaĝo',
	'lien_supprimer' => 'forigi',
	'lien_tout_afficher' => 'Afiŝi ĉion',
	'lien_visite_site' => 'viziti tiun retejon',
	'lien_visites' => '@visites@ vizitoj',
	'lien_voir_auteur' => 'Vidi tiun aŭtoron',
	'ligne' => 'Linio',
	'login' => 'Ensaluti',
	'login_acces_prive' => 'aliro al la privata spaco',
	'login_autre_identifiant' => 'ensaluti per alia salutnomo',
	'login_cookie_accepte' => 'Bonvolu agordi vian retumilon por ke ĝi akceptu ilin (almenaŭ por tiu ĉi retejo).',
	'login_cookie_oblige' => 'Por sekure ensalutiĝi en tiu retejo, vi devas akcepti la kuketojn.',
	'login_deconnexion_ok' => 'Elsalutinta.',
	'login_erreur_pass' => 'Pasvort-eraro.',
	'login_espace_prive' => 'privata spaco',
	'login_identifiant_inconnu' => 'La salutnomo « @login@ » estas nekonata.',
	'login_login' => 'Salutnomo :',
	'login_login2' => 'Salutnomo aŭ retpoŝtadreso :',
	'login_login_pass_incorrect' => '(Salutnomo aŭ pasvorto ne valida.)',
	'login_motpasseoublie' => 'ĉu pasvorto forgesita ?',
	'login_non_securise' => 'Atentu, tiu formularo ne estas sekurigita ;.
   Se vi ne volas ke via pasvorto estu fraŭde
   interkaptita ĉe la reto, bonvolu aktivigi
   Javascript-on en via retumilo',
	'login_nouvelle_tentative' => 'Nova provo',
	'login_par_ici' => 'Vi estas registrita... ĉi tien...',
	'login_pass2' => 'Pasvorto :',
	'login_preferez_refuser' => '<b>Se vi preferas rifuzi kuketojn</b>, alia konektometodo (malpli sekura) estas je via dispono :',
	'login_recharger' => 'freŝigi tiun ĉi paĝon',
	'login_rester_identifie' => 'Resti ensalutinta kelkajn tagojn', # MODIF
	'login_retour_public' => 'Reen al la publika spaco',
	'login_retour_site' => 'Reen al la publika spaco',
	'login_retoursitepublic' => 'reen al la publika spaco',
	'login_sans_cookie' => 'Ensaluto sen kuketo',
	'login_securise' => 'Sekura salutnomo',
	'login_sinscrire' => 'registriĝi', # MODIF
	'login_test_navigateur' => 'testo retumilo/rekonektiĝo',
	'login_verifiez_navigateur' => '(Kontrolu tamen ke via retumilo ne memoras pri via pasvorto...)',

	// M
	'masquer_colonne' => 'Kaŝi tiun ĉi kolumnon',
	'masquer_trad' => 'kaŝi la tradukojn',
	'message_nouveaux_identifiants_echec' => 'Ne eblas krei novajn ensalutilojn.',
	'message_nouveaux_identifiants_echec_envoi' => 'Ne eblis sendi la novajn ensalutilojn.',
	'message_nouveaux_identifiants_ok' => 'La novaj ensalutilojn estis senditaj al @email@.',
	'module_fichiers_langues' => 'Dosieroj de lingvo',

	// N
	'navigateur_pas_redirige' => 'Se via retumilo ne redirektiĝas, daŭrigu musklakante ĉi tie.',
	'numero' => 'Numero',

	// O
	'occurence' => 'Trafo',
	'onglet_affacer_base' => 'Forigi la datenbazon',
	'onglet_auteur' => 'La aŭtoro',
	'onglet_contenu_site' => 'Enhavo de la retejo',
	'onglet_evolution_visite_mod' => 'Evoluado',
	'onglet_fonctions_avances' => 'Ampleksaj funkcioj',
	'onglet_informations_personnelles' => 'Personaj datenoj',
	'onglet_interactivite' => 'Interagado',
	'onglet_messagerie' => 'Mesaĝilo',
	'onglet_repartition_rubrique' => 'Distribuo laŭ rubrikoj',
	'onglet_save_restaur_base' => 'Savkopii/restaŭri la datenbazon',
	'onglet_vider_cache' => 'Malplenigi la staplon',

	// P
	'pass_choix_pass' => 'Bonvolu elekti vian novan pasvorton :',
	'pass_erreur' => 'Eraro',
	'pass_erreur_acces_refuse' => '<b>Eraro :</b> vi ne plu havas aliron al tiu retejo.',
	'pass_erreur_code_inconnu' => '<b>Eraro :</b> tiu kodo kongruas kun neniu el la vizitantoj rajtantaj aliri tiun ĉi retejon.', # MODIF
	'pass_erreur_non_enregistre' => '<b>Eraro :</b> la retpoŝtadreso <tt>@email_oubli@</tt> ne estas registrita ĉi tie.',
	'pass_erreur_non_valide' => '<b>Eraro :</b> tiu retpoŝtadreso <tt>@email_oubli@</tt> ne validas !',
	'pass_erreur_probleme_technique' => '<b>Eraro :</b> pro teknika problemo, la retmesaĝo ne povas esti sendata.',
	'pass_espace_prive_bla' => 'La privata spaco de tiu ĉi retejo estas malfermita al
  vizitantoj, post ties registriĝo. Tio farita, vi povos
  konsulti la redaktatajn artikolojn, proponi artikolojn
  kaj partopreni en ĉiuj forumoj.', # MODIF
	'pass_forum_bla' => 'Vi petis por kontribui en forumo
  rezervita al registritaj vizitantoj.', # MODIF
	'pass_indiquez_cidessous' => 'Indiku ĉi-sube la retpoŝtadreson laŭ kiu vi
   antaŭe registriĝis. Vi
   ricevos retmesaĝon kiu indikos al vi kion fari por
   reakiri vian alir-rajton.',
	'pass_mail_passcookie' => '(tio ĉi estas aŭtomata mesaĝo)
Por reakiri alireblon al la retejo
@nom_site_spip@ (@adresse_site@)

Bonvolu iri al la jena adreso :

    @sendcookie@

Vi povos tiam entajpi novan pasvorton
kaj ensaluti.

', # MODIF
	'pass_mot_oublie' => 'Pasvorto forgesita',
	'pass_nouveau_enregistre' => 'Via nova pasvorto estas registrita.',
	'pass_nouveau_pass' => 'Nova pasvorto',
	'pass_ok' => 'JES',
	'pass_oubli_mot' => 'Pasvorto-forgeso',
	'pass_procedure_changer' => 'Por ŝanĝi vian pasvorton, specifu al ni la asociitan retpoŝtadreson el via konto.',
	'pass_quitter_fenetre' => 'Forlasi tiun fenestron',
	'pass_rappel_login' => 'Memoru : via ensalutilo (salutnomo) estas « @login@ ».',
	'pass_recevoir_mail' => 'Vi ricevos retmesaĝon indikantan al vi kiel retrovi vian aliron al la retejo.', # MODIF
	'pass_retour_public' => 'Reen al la publika spaco',
	'pass_rien_a_faire_ici' => 'Nenion por fari ĉi tie.',
	'pass_vousinscrire' => 'Registriĝi ĉe tiu retejo',
	'precedent' => 'antaŭan',
	'previsualisation' => 'Antaŭrigardo',
	'previsualiser' => 'Antaŭrigardi',

	// R
	'retour' => 'Reen',

	// S
	'spip_conforme_dtd' => 'SPIP konsideras tiun dokumenton konforma al sia DOCTYPE :',
	'squelette' => 'skeleto',
	'squelette_inclus_ligne' => 'skeleto inkluzivita, linio',
	'squelette_ligne' => 'skeleto, linio',
	'stats_visites_et_popularite' => '@visites@ vizitoj ; populareco : @popularite@',
	'suivant' => 'sekvanta',

	// T
	'taille_go' => '@taille@ Go',
	'taille_ko' => '@taille@ kb',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => '@taille@ bitokoj',
	'taille_octets_bi' => '@taille@ bitokoj',
	'texte_actualite_site_1' => 'Kiam vi estos kutimiĝinta kun la interfaco, vi povos musklaki sur « ',
	'texte_actualite_site_2' => 'kompleta interfaco',
	'texte_actualite_site_3' => ' » por malfermi pliajn eblecojn.',
	'texte_creation_automatique_vignette' => 'La aŭtomata kreado de antaŭrigardaj vinjetoj estas aktivigita ĉe tiu ĉi retejo. Se vi instalas pere de tiu ĉi formularo bildojn je la formato(j) @gd_formats@, ili estos akompanataj de vinjeto kun maksimuma grandeco de @taille_preview@ bilderoj.',
	'texte_documents_associes' => 'La sekvantaj dokumentoj estas asociitaj al la artikolo,
    sed ili ne estis rekte enmetitaj en ĝin.
    Laŭ la enpaĝigo de la publika spaco,
    ili povos aperi en formo de alkroĉitaj dokumentoj.',
	'texte_erreur_mise_niveau_base' => 'Datenbazo-eraro dum la alniveligo.
  La bildo <b>@fichier@</b> ne transŝutiĝis (artikolo @id_article@).
  Bone notu tiun referencon, reprovu la alniveligon,
  kaj fine kontrolu ke la bildoj plu aperu
en la artikoloj.',
	'texte_erreur_visiteur' => 'Vi provis eniri la privatan spacon pere de ne alir-rajtiga salutnomo.',
	'texte_inc_auth_1' => 'Vi ensalutis laŭ la
  salutnomo <b>@auth_login@</b>, sed tiu ne/ne plu ekzistas en la datenbazo.
  Provu',
	'texte_inc_auth_2' => 'rekonektiĝi',
	'texte_inc_auth_3' => ', post esti eventuale ferminta kaj
  restartiginta via retumilon.',
	'texte_inc_config' => 'La ŝanĝoj faritaj en tiuj ĉi paĝoj influas grave la
 funkciadon de via retejo. Ni konsilas al vi ne plu interveni antaŭ ol esti pli
 kutimiĝinta pri la funkciado de la SPIP-sistemo. <br /><br /><b>Pli
 ĝenerale, estas tre konsilinde lasi la mastrumadon de tiuj ĉi paĝoj
sub la respondeco de la ĉefa retejestro .</b>',
	'texte_inc_meta_1' => 'La sistemo detektis eraron dum skribado de la dosiero <code>@fichier@</code>. Bonvolu, kiel mastrumanto de la retejo,', # MODIF
	'texte_inc_meta_2' => 'kontroli la skriborajtojn',
	'texte_inc_meta_3' => 'en la dosierujo <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'Redaktataj',
	'texte_statut_poubelle' => 'en rubujo',
	'texte_statut_propose_evaluation' => 'proponita por taksado',
	'texte_statut_publie' => 'rete publikigita',
	'texte_statut_refuse' => 'rifuzita',
	'titre_ajouter_mot_cle' => 'ALDONI ŜLOSILVORTON :',
	'titre_cadre_raccourcis' => 'RAPIDAJ ALIROJ :',
	'titre_changer_couleur_interface' => 'Ŝanĝi la koloron de la interfaco',
	'titre_image_admin_article' => 'Vi povas mastrumi tiun ĉi artikolon',
	'titre_image_administrateur' => 'Mastrumanto', # MODIF
	'titre_image_aide' => 'Helpo pri tiu elemento',
	'titre_image_auteur_supprime' => 'Aŭtoro forigita',
	'titre_image_redacteur' => 'Redaktanto sen alireblo',
	'titre_image_redacteur_02' => 'Redaktanto',
	'titre_image_selecteur' => 'Montri la liston',
	'titre_image_visiteur' => 'Vizitanto',
	'titre_joindre_document' => 'ALDONI DOKUMENTON',
	'titre_mots_cles' => 'ŜLOSILVORTOJ',
	'titre_probleme_technique' => 'Atentu : teknika problemo  (SQL-servilo) malhelpas la aliron al tiu parto de la retejo. Dankon pro via komprenemo.',
	'titre_publier_document' => 'PUBLIKIGI DOKUMENTON EN TIU ĈI RUBRIKO',
	'titre_signatures_attente' => 'Subskriboj validotaj',
	'titre_signatures_confirmees' => 'Subskriboj konfirmitaj',
	'titre_statistiques' => 'Statistikoj de la retejo',
	'titre_titre_document' => 'Titolo de la dokumento :',
	'todo' => 'venonta',
	'trad_definir_reference' => 'Elekti „@titre@“ kiel referenco de la tradukoj',
	'trad_reference' => '(referenco de la traduktoj)',

	// U
	'upload_limit' => 'Tiu dosiero estas tro granda por la servilo : la maksimuma dosiergrando, kiam oni alŝutas, estas @max@.',

	// Z
	'zbug_balise_b_aval' => ' : posta B marko',
	'zbug_balise_inexistante' => 'Marko @balise@ malbone deklarita por @from@',
	'zbug_balise_sans_argument' => 'Mankas argumento en la marko @balise@',
	'zbug_boucle' => 'iteracio',
	'zbug_boucle_recursive_undef' => 'Nedifinita rekursia iteracio : @nom@',
	'zbug_calcul' => 'komputado',
	'zbug_champ_hors_boucle' => 'Kampo @champ@ eksteras iteracion',
	'zbug_champ_hors_motif' => 'Kampo @champ@ eksteras kontekston @motif@',
	'zbug_code' => 'kodo',
	'zbug_critere_inconnu' => 'Nekonata kriterio @critere@',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} pri tabelo sen atoma ĉefŝlosilo',
	'zbug_distant_interdit' => 'Ago ĉe tiu ekstera datenbazo malpermesata',
	'zbug_doublon_table_sans_cle_primaire' => 'Duobloj uzitaj ĉe tabelo, kiu ne havas simplan ĉefŝlosilon',
	'zbug_doublon_table_sans_index' => 'Duoblaĵoj en la datentabelo sen indekso',
	'zbug_erreur_boucle_double' => 'Duobla difino de la interacio @id@',
	'zbug_erreur_boucle_fermant' => 'Iteracio @id@ ne fermita',
	'zbug_erreur_boucle_syntaxe' => 'Sintakso de la iteracia @id@ ne valida',
	'zbug_erreur_compilation' => 'Kompil-eraro',
	'zbug_erreur_execution_page' => 'Eraro dum plenumo',
	'zbug_erreur_filtre' => 'Filtrilo @filtre@ nedifinita',
	'zbug_erreur_meme_parent' => 'La kriterio {meme_parent} nur aplikiĝas je iteracioj (FORUMS) aŭ (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Eraro(j) en la skeleto',
	'zbug_hors_compilation' => 'Ne kompilita',
	'zbug_info_erreur_squelette' => 'Eraro ĉe la retejo',
	'zbug_inversion_ordre_inexistant' => 'Inversigo de ne ekzistanta ordo',
	'zbug_pagination_sans_critere' => 'Marko #PAGINATION senkriteria {pagination} aŭ uzata en rekursia iteracio',
	'zbug_parametres_inclus_incorrects' => 'Ne korektaj inkludaj parametroj : @param@',
	'zbug_profile' => 'Kalkuldaŭro : @time@',
	'zbug_resultat' => 'rezulto',
	'zbug_serveur_indefini' => 'Nedifinata SQL-servilo',
	'zbug_statistiques' => 'statistikoj pri SQL-informpetoj ordigitaj laŭ daŭro',
	'zbug_table_inconnue' => 'nekonata SQL « @table@ » tabelo',
	'zxml_connus_attributs' => 'konataj atributoj',
	'zxml_de' => 'de',
	'zxml_inconnu_attribut' => 'nekonataj atributoj',
	'zxml_inconnu_balise' => 'ne konita marko',
	'zxml_inconnu_entite' => 'ne konata ento',
	'zxml_inconnu_id' => 'ne konata ID',
	'zxml_mais_de' => 'sed',
	'zxml_non_conforme' => 'ne kongrua kun la motivo',
	'zxml_non_fils' => 'ne estas filo de',
	'zxml_nonvide_balise' => 'ne malplena marko',
	'zxml_obligatoire_attribut' => 'deviga atributo sed foresta en',
	'zxml_succession_fils_incorrecte' => 'sinsekvo de filoj korekta',
	'zxml_survoler' => 'superflugi por ekvidi korektaĵojn',
	'zxml_valeur_attribut' => 'atributa valoro',
	'zxml_vide_balise' => 'malplena marko',
	'zxml_vu' => 'antaŭe vidita',
];
